@@ -63,8 +63,8 @@ class TrainModelToSQl:
                 'training_start_time': dict_init_arg["training_start_time_lst"],
                 'training_end_time': dict_init_arg["training_end_time_lst"],
                 'total_training_time': dict_init_arg["total_training_time_lst"],
-                'training_data_start_date': dict_init_arg["training_start_time_lst"],
-                'training_data_end_date': dict_init_arg["training_end_time_lst"],
+                'training_data_start_date': dict_init_arg["training_data_start_date"],
+                'training_data_end_date': dict_init_arg["training_data_end_date"],
                 'number_of_dump_data': dict_init_arg["number_of_dump_data"],
                 'number_of_training_data': dict_init_arg["number_of_training_data"],
                 'number_of_positive_samples_in_training_data': dict_init_arg["number_of_positive_samples_in_training_data"],
@@ -129,13 +129,18 @@ class TrainModelToSQl:
                 'for_': [[]],
                 'tnr': [[]],
                 'auc': [[]],
-                "return_code": "dict_init_arg['return_code']",
-                "reason": "dict_init_arg['reason']"
+                "return_code": dict_init_arg['return_code'],
+                "reason": dict_init_arg['reason']
             }   
         return result
 
-    def dict_to_dataframe(self, dict_init_arg: dict):
-        df = pd.DataFrame(data=self.performance(dict_init_arg))
+    def dict_to_dataframe(self, dict_init_arg: dict, dict_add_column=None):
+        self.need_column = self.performance(dict_init_arg)
+        if dict_add_column is not None:
+            for key in dict_add_column:
+                self.need_column[key] = dict_init_arg[key]
+        
+        df = pd.DataFrame(data=self.need_column)
         df['total_training_time'] = df.total_training_time
         df['training_data_start_date'] = df.training_data_start_date
         df['training_data_end_date'] = df.training_data_end_date
@@ -160,7 +165,9 @@ class TrainModelToSQl:
         class User(Base_Model):
             __table__ = base_table
         self.orm.create_table(Base_Model, User)
-        data = self.dict_to_dataframe(data)
+        
+        data = self.dict_to_dataframe(data, dict_add_column)
+        
         self.orm.data_to_DB(data, User)
 
 
@@ -276,6 +283,20 @@ class HitrustaiTrainTemple(GetConfArg):
         self.passwd_so_name = passwd_so_name
         self.model_name = model_name
         self.dict_init_arg = None
+        self.template_output_txt = '''
+=================================================
+INFO_MODEL_NAME: %s
+INFO_TRAINING_ID : %s
+INFO_CUSTOMER_ID: %s
+INFO_MODEL_ID: %s
+DATA_START_DATE: %s
+DATA_END_DATE: %s
+DATA_TOTAL_ROW: %s
+TRAINING_DATE: %s
+TRAINING_TIME: %s
+TRAINING_RETURN_CODE : %s
+TRAINING_REASON : %s
+        '''
 
     def error_arg_dict(self):
         dict_init_arg = {
@@ -290,6 +311,8 @@ class HitrustaiTrainTemple(GetConfArg):
             "training_start_time_lst": self.training_start_time_lst,
             "total_training_time_lst": self.total_training_time_lst,
 
+            "training_data_start_date": self.DATA_START_DATE,
+            "training_data_end_date": self.DATA_END_DARE,
             "training_end_time_lst": self.training_end_time_lst,
             "number_of_dump_data": -1,
             "number_of_training_data": -1,
@@ -343,6 +366,8 @@ class HitrustaiTrainTemple(GetConfArg):
             "training_start_time_lst": self.training_start_time_lst,
             "total_training_time_lst": self.total_training_time_lst,
 
+            "training_data_start_date": self.DATA_START_DATE,
+            "training_data_end_date": self.DATA_END_DARE,
             "training_end_time_lst": self.training_end_time_lst,
             "number_of_dump_data": self.dict_model.DATA_TOTAL_ROW,
             "number_of_training_data": self.dict_model.DATA_TOTAL_ROW_TRAIN,
@@ -399,6 +424,24 @@ class HitrustaiTrainTemple(GetConfArg):
         )
         tmts.insert_db(data=self.dict_init_arg, dict_add_column=dict_add_column)
 
+    def output_txt(self, model_name="Fraud Detect", path='./data/lib/output.txt'):
+        output_txt = self.template_output_txt % (
+            model_name,
+            self.dict_init_arg["training_id_lst"],
+            self.dict_init_arg["customer_id_lst"],
+            self.dict_init_arg["model_id_lst"],
+            self.dict_init_arg["training_data_start_date"],
+            self.dict_init_arg["training_data_end_date"],
+            self.dict_init_arg["number_of_dump_data"],
+            self.dict_init_arg["training_start_time_lst"],
+            self.dict_init_arg["total_training_time_lst"],
+            self.dict_init_arg["return_code"],
+            self.dict_init_arg["reason"],
+        )
+        with open(path, 'a') as f:
+            f.write(output_txt + "\n")
+        
+
 if __name__ == '__main__':
     from hitrustai_lab.model_train.ai_module_train import TrainModelToSQl
     dict_add_column = {
